/*
The Melting World (Beta Version)

by David Aleman

Data borrowed from Polar Science Center

Schweiger, A., R. Lindsay, J. Zhang, M. Steele, H. Stern, Uncertainty in modeled 
arctic sea ice volume, J. Geophys. Res., 
doi:10.1029/2011JC007084, 2011

Interactions: 

Press Key 1 = Display data from 1980
      Key 2 = Display data from 1985
      Key 3 = Display data from 1990
      Key 4 = Display data from 1995
      Key 5 = Display data from 2000
      Key 6 = Display data from 2005
      Key 7 = Display data from 2010
      Key 8 = Display data from 2015
      Key 9 = Animate data from 1980 - 2015

Notes to Consider:
Although it is ready to present I would have liked the program to be different. Ideally
I would have liked the individual boxes to fall down the y-axis in an animation to 
reflect ice thinning in the Arctic. This will have to wait for future edits.



*/

import controlP5.*;
import peasy.*;

ControlP5 cp5;
PeasyCam cam;

PImage img;
PFont myFont;

Table table, table80, table85,
      table90, table95, table00,
      table05, table10, table15;

int rowNums, rowNums80, rowNums85,
    rowNums90, rowNums95, rowNums00,
    rowNums05, rowNums10, rowNums15;

int hMargin = 30;
int vMargin = 50;

int yearAxis, yearAxis80, yearAxis85,
    yearAxis90, yearAxis95, yearAxis00,
    yearAxis05, yearAxis10, yearAxis15;
    
int monthAxis, monthAxis80, monthAxis85,
    monthAxis90, monthAxis95, monthAxis00,
    monthAxis05, monthAxis10, monthAxis15;

float volumeAxis, volumeAxis80, volumeAxis85,
      volumeAxis90, volumeAxis95, volumeAxis00,
      volumeAxis05, volumeAxis10, volumeAxis15;

float avgVolumeAxis, avgVolumeAxis80, avgVolumeAxis85,
      avgVolumeAxis90, avgVolumeAxis95, avgVolumeAxis00,
      avgVolumeAxis05, avgVolumeAxis10, avgVolumeAxis15;
      
float startPosition = 0;
float endPosition = 720;
float []box; 
double change = 255;
double end = 376.846;
int startVolume = 24600;
int endVolume = 15400;
int startYear = 1980;
int endYear = 2015;

color c;

boolean [] structure;
boolean [] center;
boolean resetOnDoubleClick = false;
boolean label1 = false;
boolean label2 = false;
boolean label3 = false;
boolean label4 = false;
boolean label5 = false;
boolean label6 = false;
boolean label7 = false;
boolean label8 = false;
boolean label9 = false;
boolean label10 = false;

ArrayList<Ice> ice = new ArrayList<Ice>();
ArrayList<Ice2> ice2 = new ArrayList<Ice2>();
ArrayList<Ice3> ice3 = new ArrayList<Ice3>();
ArrayList<Ice4> ice4 = new ArrayList<Ice4>();
ArrayList<Ice5> ice5 = new ArrayList<Ice5>();
ArrayList<Ice6> ice6 = new ArrayList<Ice6>();
ArrayList<Ice7> ice7 = new ArrayList<Ice7>();
ArrayList<Ice8> ice8 = new ArrayList<Ice8>();
ArrayList<Ice9> ice9 = new ArrayList<Ice9>();


void setup() {
  size(1280, 720, P3D);
  cam = new PeasyCam(this, 440); //Changed by Rodger, the original is 1620
  cp5 = new ControlP5(this);
  table = loadTable("seaIceLevel.csv", "header");
  table80 = loadTable("seaIceLevel80.csv", "header");
  table85 = loadTable("seaIceLevel85.csv", "header");
  table90 = loadTable("seaIceLevel90.csv", "header");
  table95 = loadTable("seaIceLevel95.csv", "header");
  table00 = loadTable("seaIceLevel00.csv", "header");
  table05 = loadTable("seaIceLevel05.csv", "header");
  table10 = loadTable("seaIceLevel10.csv", "header");
  table15 = loadTable("seaIceLevel15.csv", "header");
  
  rowNums = table.getRowCount();
  rowNums80 = table80.getRowCount();
  rowNums85 = table85.getRowCount();
  rowNums90 = table90.getRowCount();
  rowNums95 = table95.getRowCount();
  rowNums00 = table00.getRowCount();
  rowNums05 = table05.getRowCount();
  rowNums10 = table10.getRowCount();
  rowNums15 = table15.getRowCount();
  
  
  println();
  println("Data Size: " + rowNums + " rows");

  cp5.setAutoDraw(false);

  cam.setMinimumDistance(200);
  cam.setMaximumDistance(1800);

  img = loadImage("berg.jpg");
  img.loadPixels();
  
  getData();

  println("Year: " + ice.get(0).year);
  println("Month: " + ice.get(0).month);
  println("Volume: " + ice.get(0).volume);
  println("Volume Yearly Average: " + ice.get(0).avgVolume);
  
  

  myFont = createFont("sanFranFont.ttf", 100);
  noStroke();
}

void draw() {
  smooth();
  background(225);
 
  translate(-width/5, -height/5, 0); //Added by Rodger
  
  lights();
  scale(5);
   
  mapData();
  
  //the initial visual when sketch is running. it is under "interaction" tab
  //initial();
  //labelStart();
  label1 = true;
  
  //"interaction" tab has information of what is being drawn during keyPresses
  keyPressed();
  gui();
  //println("Volume 80s: " + ice2.get(0).volume80);
  
    //println(startPosition);
  
}